Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateStruct ¶
CreateStruct used to hide/mask sensitive fields in input. This currently supports only `struct` and `string` fields when an `int` field is provided for masking an error is emitted.When no fields are provided for masking it emits an error with informative message
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.